import pytest

from bw2scaffold.cli import finish


def test_finish(capfd):
    """Verify that an empty call to finish raises an AssertionError."""
    with pytest.raises(AssertionError):
        finish("")



import logging
import os
import platform
from pathlib import Path
from subprocess import run

logger = logging.getLogger(__name__)


def install_autenv() -> None:
    """Install autoenv to manage environmental variables automatically

    Autoenv works in UNIX systems, it uses a .sh file to be activated \
    and it modifies the ~/.zshrc or  ~/.bashrc.
    See more here https://github.com/hyperupcall/autoenv
    """
    UNIX_AUTOENV_PATH = f"{os.getenv('HOME')}/.autoenv"
    # Get OS
    if "Linux" in platform.system():
        # Verify if '~/.autoenv' exists
        if Path(UNIX_AUTOENV_PATH).exists():
            logger.warning("autoenv already installed [bold yellow](skipping)[/]")
            return

        if "zsh" in Path(str(os.getenv("SHELL"))).name:
            run(
                "git clone "
                f"'https://github.com/hyperupcall/autoenv' {UNIX_AUTOENV_PATH}",
                shell=True,
            )
            run(
                "printf '%s\n' " "'source ~/.autoenv/activate.sh' >> ~/.zshrc",
                shell=True,
            )
        if "bash" in Path(str(os.getenv("SHELL"))).name:
            run(
                "git clone "
                f"'https://github.com/hyperupcall/autoenv' {UNIX_AUTOENV_PATH}",
                shell=True,
            )
            run(
                "printf '%s\n' 'source ~/.autoenv/activate.sh' >> ~/.bashrc",
                shell=True,
            )
        logger.info(f"Autoenv installed in: {UNIX_AUTOENV_PATH}")
        return
    else:
        logger.error(
            "Autoenv works only in UNIX-like systems [bold yellow](skipping)[/]",
            extra={"markup": True},
        )


def install_graphviz() -> None:
    """Install graphviz to plot callgraph

    Graphviz requires sudo rights.  Why bypass it by installing an conda-forge built
    Remember to use conda-forge channel
    """
    # Get OS
    if "Linux" in platform.system():

        if "zsh" in Path(str(os.getenv("SHELL"))).name:
            run(
                "conda install conda-forge::graphviz",
                shell=True,
            )
        if "bash" in Path(str(os.getenv("SHELL"))).name:
            run(
                "conda",
                "install",
                "conda-forge::graphviz",
                shell=True,
            )
        logger.info("Graphviz is installed")
        return
    else:
        logger.error(
            "Graphviz works only in UNIX-like systems [bold yellow](skipping)[/]",
            extra={"markup": True},
        )



from typing import Any, Mapping, Protocol, Union, runtime_checkable

from . import logging

logger = logging.getLogger(__name__)

# TODO: Finish bw2data protocols and validators to ensure robustness among version


@runtime_checkable
class BW2DatabasesContainer(Protocol):
    """Interface of bw2data.databases agnostic to bw2data versions"""

    filename: str

    def __getitem__(self, database_name: str) -> Mapping:
        ...


def ValidateDatabasesContainer(databases: Any) -> Any:
    """Verifies databases footprint"""
    try:
        assert isinstance(
            databases, BW2DatabasesContainer
        ), f"{databases} is not a compatible {BW2DatabasesContainer} type"
        return databases
    except AssertionError:
        logger.error(
            "The databases container has an incompatible footprint "
            "[bold blue]hint: [/] downgrade your [b]bw2data[/] version]"
        )


def bw2data_databases_importer() -> Union[BW2DatabasesContainer, None]:
    try:
        import bw2data  # type: ignore

        databases = ValidateDatabasesContainer(bw2data.databases)
        return databases
    except ImportError:
        logger.error(
            "Failed to import bw2data. "
            "[bold blue]hint:[/] install it by doing `[b]pip install bw2data[/]`"
        )
        return None



# %%
# © [2024] Luxembourg Institute of Science and Technology. All Rights Reserved
"""
Command Line Interface for bw2scaffold
"""

from pathlib import Path
from typing import Optional

import typer
from typing_extensions import Annotated

from .bw2utils import logging
from .directories import create_env_vars, create_structure
from .plugins import install_autenv, install_graphviz
from .prepare import create_callgraph

# import logging

logger = logging.getLogger("bw2scaffold")

app = typer.Typer(rich_markup_mode="rich")


@app.command(
    help="[bold red]Packs up[/bold red] a project created with "
    "bw2scaffold and verifies its quality."
)
def finish(
    input_file: Annotated[str, typer.Argument(help="Path of run.py")],
    output_file: Annotated[
        str, typer.Argument(help="Path to export the callgraph")
    ] = "data/callgraph.png",
    function: Annotated[
        str,
        typer.Option(
            "--function",
            "-func",
            help="Name of the function containing the main pipeline",
        ),
    ] = "main",
):
    """Pack up a repository created with bw2scaffold and verifies its quality.

    This command is underdevelopment. It only generates a callgraph.
    """
    create_callgraph(input_file, output_file, function)

    logger.info(
        ":sparkles:[bold green]Success![/bold green] "
        ":package: :heavy_check_mark: Your project has been "
        "checked and packed :heavy_check_mark: :package:"
    )


@app.command(
    help="[bold green]Prepares[/bold green] a "
    "[link=https://docs.brightway.dev/][u]brightway[/u][/link] project template "
    "and starts your LCA modelling."
)
def start(
    project_name: Annotated[str, typer.Argument()],
    plugins: Annotated[
        Optional[bool],
        typer.Option(
            "--full",
            "-f",
            help=(
                "Installs recommended shell plugins that facilitate work. "
                "Works only in UNIX-like systems"
            ),
        ),
    ] = False,
    verbose: Annotated[
        bool, typer.Option("--verbose", "-v", help="Activate to have verbose logging")
    ] = False,
    email: Annotated[Optional[str], typer.Option()] = None,
):
    """Prepares a brightway project template and start your LCA modelling.

    This command creates an LCA template project compatible with the
    brightway software ecosystem.

    """
    logger = logging.getLogger("bw2scaffold", debug=verbose)

    parent = Path() / project_name
    create_structure(parent)
    create_env_vars(parent)
    logger.info(
        f":sparkles:[bold green]Success![/bold green] your "
        f"brightway-based repo has been created at: \n \n {parent.resolve()} \n"
    )

    if plugins:
        logger.debug("Installing plugins")
        install_autenv()
        install_graphviz()


def run():
    app()



from typing import Any, Dict, List, Literal, Optional, Tuple, Union

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    FilePath,
    RootModel,
    TypeAdapter,
    model_validator,
)
from typing_extensions import Annotated, Self

# from .protocols import bw2data_databases_importer, BW2DatabasesContainer
from . import logging

logger = logging.getLogger(__name__)

# TODO: Build data validators for ecoinvent and ecoinvent-act-type combinations
# TODO: Build data validators for reading yaml files (from list to tuple)


class CharacterizationFactorEcoInvent(BaseModel):
    method: str
    category: str
    indicator: str
    name: str
    compartment: str
    subcompartment: str
    cf: Union[float, Literal["NA"]] = Field(default="NA")  # NA represents a placeholder

    # based on: https://docs.pydantic.dev/latest/concepts/models/#validating-data
    model_config = ConfigDict(revalidate_instances="always")


class BWNode(BaseModel):
    categories: Optional[Tuple[str, str]] = None
    code: str
    name: str
    cas_number: Annotated[
        Optional[str],
        Field(validation_alias="CAS number", serialization_alias="CAS number"),
    ] = None
    unit: Optional[str] = None
    filename: Optional[FilePath] = None
    synonyms: Optional[List[str]] = []
    database: str
    parameters: Optional[List[Dict]] = None
    reference_product: Annotated[
        Optional[str],
        Field(
            validation_alias="reference product",
            serialization_alias="reference product",
        ),
    ] = None
    production_amount: Annotated[
        Optional[str],
        Field(
            validation_alias="production amount",
            serialization_alias="production amount",
        ),
    ] = None
    activity_type: Annotated[
        Optional[
            Literal[
                "market activity",
                "market group",
                "ordinary transforming activity",
                "production mix",
                None,
            ]
        ],
        Field(
            validation_alias="activity type",
            serialization_alias="activity type",
        ),
    ] = None
    type: Literal[
        "emission",
        "economic",
        "inventory indicator",
        "natural resource",
        "process",
        None,
    ] = None
    exchanges: Optional[List[Any]] = []

    # To set by_alias permanently as shown in:
    # https://stackoverflow.com/questions/78319788/\
    # how-to-make-serialization-alias-the-default-behavior-in-pydantic-basemodel
    def model_dump(self, **kwargs) -> dict[str, Any]:
        return super().model_dump(by_alias=True, **kwargs)

    # based on: https://docs.pydantic.dev/latest/concepts/models/#validating-data
    model_config = ConfigDict(
        revalidate_instances="always", extra="allow", populate_by_name=True
    )

    @model_validator(mode="after")
    def validate_ei_biosphere_node(self) -> Self:
        ei_biosphere_types = [
            "emission",
            "economic",
            "inventory indicator",
            "natural resource",
        ]
        categories_type: TypeAdapter = TypeAdapter(Tuple["str", "str"])

        if self.type in ei_biosphere_types:
            try:
                assert categories_type.validate_python(self.categories)
            except AssertionError:
                logger.error(
                    "This `seems` to be a biosphere node."
                    "The field `categories` is missing"
                )
        return self

    # TODO: Build database validator. It should alert if a database does not exist.


#     @field_validator('database')
#     @classmethod
#     def check_database_existance(cls, database_name:str) -> str: ...


BWDatabaseDict = RootModel[Dict[Tuple[str, str], BWNode]]



"""Test the directories module."""
import os
from importlib import resources as impresources

import yaml

import bw2scaffold
from bw2scaffold.directories import create_structure


def check_files_exist(file_dict, parent=""):
    """
    Recursively checks if files exist based on a nested dictionary structure,
    using a parent directory.

    Args:

        file_dict (dict): String values or nested dictionaries as values.
        parent (str): The current directory path to prefix to each key.

    Returns:
        bool: True if all files exist, False otherwise.
    """
    for key, value in file_dict.items():
        # Construct the new path based on the parent and the current key
        current_path = os.path.join(parent, key)

        if isinstance(value, str):
            # Construct the file path based on parent directory and key
            file_path = os.path.join(parent, key)
            if not os.path.isfile(file_path):
                print(f"File does not exist: {file_path}")
                return False
        elif isinstance(value, dict):
            # Recurse deeper into the structure with the updated path
            if not check_files_exist(value, current_path):
                return False
        else:
            # Raise an error for any unexpected value type
            raise ValueError(f"Unexpected value type at key {key}: {type(value)}")

    return True


def test_create_structure(tmp_path):
    """
    Verify that all the required files from the directories.yaml spec are created.

    """
    project_name = "sample project"

    parent = tmp_path / project_name
    create_structure(parent)
    assert parent.exists()

    dirs_file = impresources.files(bw2scaffold) / "templates" / "directories.yaml"
    print(f"test path {tmp_path}")
    print(f"Temp file {dirs_file}")
    with dirs_file.open(mode="r", encoding="utf-8") as f:
        dirs_config = yaml.safe_load(f)

    assert check_files_exist(dirs_config, parent=parent)



# UNder dev
# flake8: noqa
# type: ignore
import re
from itertools import count
from pathlib import Path
from pprint import pprint

import bw2calc as bc
import bw2data as bd
import bw2io.importers
import matplotlib.pyplot as plt
import networkx as nx
import numpy as np
import yaml
from pacha.engine.core.utils import Reader, Writer
from pyvis.network import Network

stop_flying = ["#00B5C0", "#0E304B", "#FDD003", "#FF3967"]
more_and_more = ["#76C498", "#E1CE53", "#F06B39", "#AD1234", "#372B3B"]


def create_ei_network_2(key_list=None, n_layers=None, complete=False):
    """:return networkx.DiGraph(): networkx directed graph object

    Args:
      key:  (Default value = None)
      n_layers:  (Default value = None)
      complete:  (Default value = False)

    Returns:

    """

    graph = nx.DiGraph()

    if not complete:
        processed = []
        # selecting all processes
        for n in range(n_layers + 1):
            if n == 0:
                n_layer = key_list  # begins with layer 0 (ego)
            else:
                upper_layer = []
                for key in n_layer:
                    if key not in processed:
                        # upper_layer = []

                        # adds consumer process (to)
                        graph.add_node(
                            str(key),
                            activity_type=bd.get_activity(key)["activity type"],
                            location=bd.get_activity(key)["location"],
                            name=bd.get_activity(key)["name"],
                            rp=bd.get_activity(key)["reference product"],
                        )
                        for exchange in bd.get_activity(key).technosphere():
                            # adds supplier node (from)
                            graph.add_node(
                                str(exchange.input.key),
                                activity_type=exchange.input.get("activity type"),
                                location=exchange.input.get("location"),
                                name=exchange.input.get("name"),
                                rp=exchange.input.get("reference product"),
                            )

                            graph.add_edges_from(
                                [
                                    (
                                        str(exchange.input.key),
                                        str(exchange.output.key),
                                        {
                                            "amount": exchange["amount"],
                                            "product": exchange["name"],
                                        },
                                    )
                                ]
                            )

                            upper_layer += [exchange.input.key]
                        processed += [key]
                n_layer = list(
                    set(upper_layer)
                )  # the n+1 layer (suppliers) become consumers for next iteration

    else:
        for key in key_list:
            for activity in bd.Database(key[0]):
                # adds nodes with attributes
                graph.add_node(
                    activity["code"],
                    activity_type=activity["activity type"],
                    location=activity["location"],
                    rp=activity["reference product"],
                )

                # adds edges with attributes
                for exchange in activity.technosphere():
                    graph.add_edges_from(
                        [
                            (
                                str(exchange.input.key),
                                str(exchange.output.key),
                                {
                                    "amount": exchange["amount"],
                                    "product": exchange["name"],
                                },
                            )
                        ]
                    )

    return graph


def plot_ei_dyn_network(network, property, html_name="example"):
    """

    Args:
      network:
      property:

    Returns:

    """
    groups = set(nx.get_node_attributes(network, property).values())
    # maps each unique string to a number and color:
    mapping_numbers = dict(zip(sorted(groups), count()))
    mapping_colors = dict(zip(sorted(groups), stop_flying))
    # Assigns a color to an specific value
    nodes = network.nodes()
    outdegrees = network.out_degree
    net = Network(directed=True)
    net.width = "2100px"
    net.height = "1000px"

    for node, node_attrs in network.nodes(data=True):
        net.add_node(
            node,
            label=node_attrs["name"] + f" [{node_attrs['location']}]",
            size=max(outdegrees[node] * 10, 1),
            color=mapping_colors[node_attrs[property]],
        )

    for source, target, edge_attrs in network.edges(data=True):
        net.add_edge(
            source, target, title=edge_attrs["product"], arrowStrikethrough=False
        )
    net.show_buttons(
        filter_=[
            "physics",
            # "nodes",
            # "edges",
            "layout",
            # "interaction",
            # "manipulation",
            # "physics",
            # "selection",
            # "renderer",
        ]
    )
    net.show(f"{html_name}.html")


############################
bd.projects.set_current("default")
ei = bd.Database("ecoinvent36")
bio = bd.Database("biosphere3")
act1 = ei.get("fd1f8146d43d39613d13f409771d3b19")
gold = ei.get("eef967d84f1d5dbef61e0eb6e8167488")
gold1 = ei.get("2c04e4079f0ffaa934f0f949c154f97b")
g1 = create_ei_network_2([act1.key], 1)
plot_ei_dyn_network(g1, "activity_type")

del bd.databases["foreground"]

path_foreground = "experiment_base/templates/foreground_database.yaml"
with open(path_foreground, "r") as f:
    # dicto = yaml.safe_load(f.read())
    string = f.read()
    string_corrected = re.sub(
        r"\((.*)\)", lambda x: f" !!python/tuple [{x.groups()[0]}]", string
    )
    dicto = yaml.load(string_corrected, Loader=yaml.Loader)

bd.Database("foreground").write(dicto)
method = ("IPCC 2013", "climate change", "GWP 100a")
fg = bd.Database("foreground")
act_test = fg.get("fishmeal_prod")
heat = bd.get_activity(("ecoinvent36", "29e29e3f34580860d08c102328eee797"))

g1 = create_ei_network_2([act.key for act in fg], 1)
plot_ei_dyn_network(g1, "activity_type")
plot_ei_dyn_network(g2, "activity_type")

lca = bc.LCA({act1: 1}, method=method)
lca.lci(factorize=True)
lca.lcia()
print(lca.score)

lca.redo_lci({heat: 1})
lca.lcia_calculation()
lca.score


# charac_bio = lca.characterization_matrix.dot(lca.biosphere_matrix)
lcam = bc.MonteCarloLCA({act_test: 1}, method=method, seed=42)
lcam.load_data()
lcam.lci(factorize=True)
lcam.lcia_calculation()
lcam.score

lcam = bc.MonteCarloLCA({act_test: 1}, seed=42)
_ = next(lcam)
lcam.decompose_technosphere()
lcam.switch_method(method)
lcam.lcia_calculation()
print(lcam.score)

lcam.redo_lci({heat: 1})
lcam.lcia_calculation()
lcam.score


lca = bc.LCA({act_test: 1})
lca.load_lci_data()
lca.build_demand_array()

lca.technosphere_matrix = lcam.technosphere_matrix
lca.biosphere_matrix = lcam.biosphere_matrix
lca.decompose_technosphere()


lca.build_demand_array({act_test: 1})
lca.demand = {act_test: 1}
lca.lci_calculation()
lca.switch_method(method)
lca.lcia_calculation()
lca.score

lca.build_demand_array({heat: 1})
lca.demand = {heat: 1}
lca.lci_calculation()
lca.switch_method(method)
lca.lcia_calculation()
lca.score


lca.switch_method(method)
lca.lcia_calculation()
print(lca.score)

lca.redo_lci({heat: 1})
lca.lcia_calculation()
print(lca.score)


lcam = bc.MonteCarloLCA({heat: 1}, method=method, seed=42)
lcam = bc.MonteCarloLCA({heat: 1}, seed=42)
lcam.redo_lci({act_test: 1})
lcam.lcia_calculation()
lcam.score
for i in range(1000):
    next(lcam)
    datum.append(lcam.score)

#########################################################################
####
string = ""  # this is code to convert tuples from yaml to dicts
re.sub(r"\(.*\)", lambda x: f"!!python/tuple {x.group()}", string)
re.sub(r"(.*)\(.*\)", "!!python/tuple ", string)
#######


fm = bd.get_activity(("foreground", "fishmeal_prod"))
heat = bd.get_activity(("ecoinvent36", "29e29e3f34580860d08c102328eee797"))
vsteel = bd.get_activity(("foreground", "landed_anchovy_steel"))
vwood = bd.get_activity(("foreground", "landed_anchovy_wooden"))
diesel = bd.get_activity(("foreground", "diesel_peru"))


list_keys = [
    ("foreground", "fishmeal_prod"),
    ("foreground", "heat_peru"),
]
op = Reader.op_from_ei(
    "ABM_SN",
    list_keys,
    outputs={"fishmeal, 65-67% protein"},
    quantitiy_warehouses=1,
    list_methods=[("IPCC 2013", "climate change", "GWP 100a")],
)
Writer.excel_from_op("text.xlsx", op, head_idx=True)

op_new = Reader.op_from_excel("text.xlsx", head_idx=True)



"""
Logging module that prepares a custom logger. Overrides logging built-in package
"""
import logging
from logging import Logger

from rich.logging import RichHandler

# formatter = logging.Formatter("%(levelname)s | %(funcName)s | %(message)s")

logger = logging.getLogger("bw2scaffold")
logger.handlers = []
handler = RichHandler(show_path=False, markup=True)
logger.addHandler(handler)
logger.setLevel(logging.INFO)


def getLogger(name: str, debug: bool = False) -> Logger:
    logger = logging.getLogger(name)

    if debug:
        logger.setLevel(logging.DEBUG)
        logger.handlers = []
        handler = RichHandler(
            show_path=True,
            omit_repeated_times=False,
            markup=True,
            rich_tracebacks=True,
        )
        logger.addHandler(handler)
    return logger



# © [2024] Luxembourg Institute of Science and Technology. All Rights Reserved
import logging
import os
from pathlib import Path
from subprocess import run
from typing import Any, Dict, Literal, Union

import yaml
from jinja2 import Environment, PackageLoader
from rich.progress import Progress, SpinnerColumn, TextColumn

logger = logging.getLogger(__name__)

# TODO try with minimum-dependencies


ENV = Environment(
    loader=PackageLoader("bw2scaffold", "templates"),
)

# Global variable
TEMPLATE_PARAMS = {}


def get_dependencies(manager: Union[Literal["conda"], Literal["pip"]]):
    """Gets current dependencies from conda and pip.

    Returns:
        conda_str: conda string corresponding to ``environment.yaml``
        pip_str: pip dependencies corresponding to ``requirements.txt``.

    """
    if manager == "conda":
        try:
            proc = run(
                [
                    "conda",
                    "env",
                    "export",
                    "--name",
                    os.environ["CONDA_DEFAULT_ENV"],
                    "--no-builds",
                ],
                text=True,
                capture_output=True,
            ).stdout

        except Exception:
            logger.warning("no conda env identified")
            proc = None

    if manager == "pip":

        proc = run(
            [
                "pip",
                "list",
                "--format=freeze",
            ],
            text=True,
            capture_output=True,
        ).stdout

    return proc


def parse_template(name: str, template_params: Dict[str, Any]) -> str:
    """Renders a template from a jinja2 template.

    Uses :py:mod:`jinja2` templates to render a new file using\
    the `template_params` dict.

    Args:
        name: Name of the jinja2 template with a ``*.template`` extension.

        template_params: Contains a dict of parameters of all templates.

    Returns:
        raw_file: Rendered string content that will be written into a file.
    """

    template = ENV.get_template(
        name,
    )

    return template.render(**template_params)


def create_node(nodes: Union[dict], parent: Path):
    """Iterates through a structure dict and creates the node file.

    #TODO: verify that the nodes are possible to create.

    Args:
        nodes: Dict containing the tree structure of the folders that will be created.
        parent: Absolute path of the parent path that will \
        contain the `nodes` tree substructure.
    """
    for name, node in nodes.items():
        if isinstance(node, dict):
            sub_parent = parent / name
            create_node(node, sub_parent)

        else:
            """
            The final leaf of the tree has the file name as \
            key and the template name as value, e.g.,:
            {'README.md': 'README.md.template' }
            """

            parent.mkdir(parents=True, exist_ok=True)
            if name == "environment.yaml":
                TEMPLATE_PARAMS["dependencies_conda"] = get_dependencies("conda")
            if name == "requirements.txt":
                TEMPLATE_PARAMS["dependencies_pip"] = get_dependencies("pip")

            with open((parent / name), encoding="utf-8", mode="w") as f:
                f.write(parse_template(node, TEMPLATE_PARAMS))


def create_structure(project_name: Path, parameters: dict = {}):
    """Creates a tree of folder as suggested by the lca-protocol

    Args:
        project_name: Path with location of the new project folder
        parameters: Parameters to feed into the template
    """
    with Progress(
        SpinnerColumn(),
        TextColumn("[progress.description]{task.description}"),
        transient=True,
    ) as progress:

        progress.add_task(description="Creating folders...", total=None)
        nodes = yaml.safe_load(
            ENV.get_template("directories.yaml").render(**parameters)
        )
        create_node(nodes, project_name)


def create_env_vars(project_name: Path):
    """Creates a .env file containing environmental variables specific to the project"""
    with Progress(
        SpinnerColumn(),
        TextColumn("[progress.description]{task.description}"),
        transient=True,
    ) as progress:

        progress.add_task(description="Setting environmental variables...", total=None)

        # TODO: This should read a template of environmental variables
        BRIGHTWAY2_DIR = ".bw2projects"
        path_projects = project_name.absolute() / f"{BRIGHTWAY2_DIR}"
        path_projects.mkdir(parents=True, exist_ok=True)
        env_vars = [
            f"BRIGHTWAY2_DIR={path_projects}\n",
            f"export BRIGHTWAY2_DIR={path_projects}\n",
            "AUTOENV_ENABLE_LEAVE=True\n",
        ]

        with open(project_name / ".env", "w") as f:
            f.writelines(env_vars)

        env_leave_vars = ["unset AUTOENV_ENABLE_LEAVE\n", "unset BRIGHTWAY2_DIR\n"]

        with open(project_name / ".env.leave", "w") as f:
            f.writelines(env_leave_vars)



from rich import print


def prepare():
    print("I am preparing some data")


def read_data():
    print("I am reading some data")
    return None


def build_lci() -> None:
    print("I am building LCI")
    return None


def lcia_step() -> float:
    print("I am building LCIA")
    return None


def main():
    prepare()
    build_lci()
    lcia_step()
    print("Main is done")


if __name__ == "__main__":
    main()



from code2flow.engine import SubsetParams, code2flow


def create_callgraph(
    file_path_input: str, file_path_output: str, function: str = "main"
):
    """Creates a callgraph of the workflow"""

    subset_params = SubsetParams(function, 5, 5)

    code2flow(
        file_path_input,
        file_path_output,
        subset_params=subset_params,
        hide_legend=False,
    )
